# dcode.py

Welcome to dcode.py - the package designed to do everything!

## Installation

Linux / macOS (python3):

``` zsh
python3 -m pip install dcode.py
```

Linux  / macOS (python2):

``` zsh
python -m pip install dcode.py
```

Windows:

``` zsh
py -m pip install dcode.py
```

## Modules

Below are listed the modules in dcode:

* dcode.io.file

## Docs

[dcode documentation](https://github.com/dylanopen/dcode.py/blob/main/docs.md)
